@@ -11,9 +11,12 @@ pub mod noise;
 pub mod rgbimage;
 pub mod stats;
 pub mod vector;
+pub mod quaternion;
 pub mod enums;
 pub mod path;
 pub mod util;
 pub mod imagerot;
 pub mod blur;
 pub mod lowpass;
+pub mod quality;
+pub mod prelude;
